@@ -94,12 +94,12 @@ class Journalfile:
     def getHashes(self):
         '''Returns a list of hashvalues of successful archived emails'''
         hashvalues=[]
-        hashre=re.compile('^.+\(SUCCESS\) ARCHIVED\s+"(\S+)": archived')
+        hashre=re.compile('^.+\(SUCCESS\) ARCHIVED\s+"(\S+:)?(\S+)": archived')
         jf=self.__open()
         for line in jf:
             m=hashre.match(line)
             if m:
-                hashvalues.append(m.group(1))
+                hashvalues.append(m.group(2))
         hashvalues.reverse()
         return hashvalues 
 
